Copy Object: {$ ctrl.model.container $}/{$ ctrl.model.path $}
Destination Container
This field is required. This container does not exist.
Destination Object
This field is required. This name already exists.

You can copy objects. You have to create destination container prior to copy.

You can specify folder by using '/' at destination object field. For example, if you want to copy object under the folder named 'folder1', you need to specify destination object like 'folder1/[your object name]'.